HBle class

Constructors

HBle()

Properties

connectHBleDevice HBleDevice?
getter/setter pair
deviceListen NativeSendToDeviceListen
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sendHandle HBleSendHandle
latefinal

Methods

addHistoryScanListen(dynamic scanListen(List<HBleDevice> devices)) → void
addNotificationListen(dynamic notification(String serviceUuid, String characteristicsUuid, Uint8List bytes)) → void
addScanListen(dynamic scanListen(HBleDevice device)) → void
characteristicsNotification({required HBleDeviceServicesCharacteristics characteristics, required bool enable}) → void
connect({required HBleDevice device, required dynamic deviceStatus(ConnectionStatus status)}) → void
death() → void
disConnectDevice() → void
discoverService({required HBleDevice device, required dynamic deviceServices(HBleDeviceServices services)}) → void
getCharacteristics({required HBleDeviceServices services, required dynamic deviceServicesCharacteristics(HBleDeviceServicesCharacteristics characteristics)}) → void
getHBleState(dynamic complete(HBleState state)) → void
getHistoryScanList(int time) → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
scan() → void
secureWriteCharacteristics({required HBleDeviceServicesCharacteristics characteristics, required Uint8List value, bool withResponse = false}) → void
stopScan() → void
toString() String
A string representation of this object.
inherited
writeCharacteristics({required HBleDeviceServicesCharacteristics characteristics, required Uint8List value, bool withResponse = false, dynamic writeResult(bool success)?}) → void

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

bleBroadcastState bool
getter/setter pair
bleState bool
getter/setter pair
getHBleStateComplete ↔ dynamic Function(HBleState)?
getter/setter pair
onePageSentMainTime int
getter/setter pair
printDebug bool
getter/setter pair
scanNow bool
getter/setter pair
sendingWait int
getter/setter pair