HBleHistoryScanListen class

Constructors

HBleHistoryScanListen()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addListens(dynamic listen(List<HBleDevice> device)) int
removeListens(int id) → void
setHBleDevices(int id, List data) → dynamic