NativeSendToDeviceListen class

Constructors

NativeSendToDeviceListen({required HBle ble})

Properties

ble HBle
final
deviceServices ↔ dynamic Function(HBleDeviceServices services)?
getter/setter pair
deviceServicesCharacteristics ↔ dynamic Function(HBleDeviceServicesCharacteristics characteristics)?
getter/setter pair
deviceStatus ↔ dynamic Function(ConnectionStatus status)?
getter/setter pair
doDeviceServicesCharacteristicsFunc bool
getter/setter pair
doDeviceServicesFunc bool
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
notification ↔ dynamic Function(String serviceUuid, String characteristicsUuid, Uint8List bytes)?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
writeResult ↔ dynamic Function(bool success)?
getter/setter pair

Methods

death() → void
identifierIsMe(String identifier) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setInformation({required Map data}) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

addListens(NativeSendToDeviceListen l) → void
removeListens(NativeSendToDeviceListen l) → void
setDeviceInformation({required String identifier, required Map data}) → void